@@ -50,3 +50,16 @@ int setenv(const char *name, const char *value, int overwrite);
 #define         TIOCM_ST        0010            /* secondary transmit */
 #define         TIOCM_SR        0020            /* secondary receive */
 #endif
+
+#ifndef HAVE_STRLCPY
+size_t strlcpy(char *dst, const char *src, size_t siz);
+#endif
+
+/* cyberpower needs this to compile on IRIX. 
+ *
+ * Whether this actually works is another story.
+ */
+
+#ifndef CRTSCTS
+   #define CRTSCTS   020000000000
+#endif
